require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xclusterproperty',
  dscmeta_resource_friendly_name: 'xClusterProperty',
  dscmeta_resource_name: 'MSFT_xClusterProperty',
  dscmeta_module_name: 'xFailOverCluster',
  dscmeta_module_version: '1.10.0.0',
  docs: 'The DSC xClusterProperty resource type.
         Automatically generated from version 1.10.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Stores administrative comments about the cluster. The following table summarizes the attributes of the Description property.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_clusterloglevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls the level of cluster logging.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_samesubnetdelay: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls the delay, in milliseconds, between netft heartbeats.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_crosssitethreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls how many Cluster Service heartbeats can be missed across sites before it determines that Cluster Service has stopped responding.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_databasereadwritemode: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the read/write mode for the cluster database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_quarantinethreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the quarantine threshold for a node, in minutes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_drainonshutdown: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies whether to enable Node Drain for a cluster.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_defaultnetworkrole: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the role that the cluster automatically assigns to any newly discovered or created network.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the cluster.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clusterlogsize: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls the maximum size of the cluster log files on each of the nodes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_quarantineduration: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the quarantine duration for a node, in seconds.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dynamicquorum: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Enables the cluster to change the required number of nodes that need to participate in quorum when nodes shut down or crash.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_crosssitedelay: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls the time interval, in milliseconds, that the cluster network driver waits between sending Cluster Service heartbeats across sites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_crosssubnetdelay: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls the time interval, in milliseconds, that the cluster network driver waits between sending Cluster Service heartbeats across subnets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_netftipsecenabled: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies whether Internet Protocol Security (IPSec) encryption is enabled for inter-node cluster communication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_crosssubnetthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls how many Cluster Service heartbeats can be missed across subnets before it determines that Cluster Service has stopped responding.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_shutdowntimeoutinminutes: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how many minutes after a system shutdown is initiated that the failover cluster service will wait for resources to go offline.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_addevictdelay: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how many seconds after a node is evicted that the failover cluster service will wait before adding a new node.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_preferredsite: {
      type: 'Optional[String]',
      desc: 'Specifies the preferred site for a site-aware cluster.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_samesubnetthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Controls how many heartbeats can be missed on the same subnet before the route is declared as unreachable.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
